[−][src]Enum unicode_types::old_hungarian::OldHungarian
An enum to represent all characters in the OldHungarian block.
Variants
CapitalLetterA\u{10c80}: '𐲀'
CapitalLetterAa\u{10c81}: '𐲁'
CapitalLetterEb\u{10c82}: '𐲂'
CapitalLetterAmb\u{10c83}: '𐲃'
CapitalLetterEc\u{10c84}: '𐲄'
CapitalLetterEnc\u{10c85}: '𐲅'
CapitalLetterEcs\u{10c86}: '𐲆'
CapitalLetterEd\u{10c87}: '𐲇'
CapitalLetterAnd\u{10c88}: '𐲈'
CapitalLetterE\u{10c89}: '𐲉'
CapitalLetterCloseE\u{10c8a}: '𐲊'
CapitalLetterEe\u{10c8b}: '𐲋'
CapitalLetterEf\u{10c8c}: '𐲌'
CapitalLetterEg\u{10c8d}: '𐲍'
CapitalLetterEgy\u{10c8e}: '𐲎'
CapitalLetterEh\u{10c8f}: '𐲏'
CapitalLetterI\u{10c90}: '𐲐'
CapitalLetterIi\u{10c91}: '𐲑'
CapitalLetterEj\u{10c92}: '𐲒'
CapitalLetterEk\u{10c93}: '𐲓'
CapitalLetterAk\u{10c94}: '𐲔'
CapitalLetterUnk\u{10c95}: '𐲕'
CapitalLetterEl\u{10c96}: '𐲖'
CapitalLetterEly\u{10c97}: '𐲗'
CapitalLetterEm\u{10c98}: '𐲘'
CapitalLetterEn\u{10c99}: '𐲙'
CapitalLetterEny\u{10c9a}: '𐲚'
CapitalLetterO\u{10c9b}: '𐲛'
CapitalLetterOo\u{10c9c}: '𐲜'
CapitalLetterNikolsburgOe\u{10c9d}: '𐲝'
CapitalLetterRudimentaOe\u{10c9e}: '𐲞'
CapitalLetterOee\u{10c9f}: '𐲟'
CapitalLetterEp\u{10ca0}: '𐲠'
CapitalLetterEmp\u{10ca1}: '𐲡'
CapitalLetterEr\u{10ca2}: '𐲢'
CapitalLetterShortEr\u{10ca3}: '𐲣'
CapitalLetterEs\u{10ca4}: '𐲤'
CapitalLetterEsz\u{10ca5}: '𐲥'
CapitalLetterEt\u{10ca6}: '𐲦'
CapitalLetterEnt\u{10ca7}: '𐲧'
CapitalLetterEty\u{10ca8}: '𐲨'
CapitalLetterEch\u{10ca9}: '𐲩'
CapitalLetterU\u{10caa}: '𐲪'
CapitalLetterUu\u{10cab}: '𐲫'
CapitalLetterNikolsburgUe\u{10cac}: '𐲬'
CapitalLetterRudimentaUe\u{10cad}: '𐲭'
CapitalLetterEv\u{10cae}: '𐲮'
CapitalLetterEz\u{10caf}: '𐲯'
CapitalLetterEzs\u{10cb0}: '𐲰'
CapitalLetterEntDashShapedSign\u{10cb1}: '𐲱'
CapitalLetterUs\u{10cb2}: '𐲲'
SmallLetterA\u{10cc0}: '𐳀'
SmallLetterAa\u{10cc1}: '𐳁'
SmallLetterEb\u{10cc2}: '𐳂'
SmallLetterAmb\u{10cc3}: '𐳃'
SmallLetterEc\u{10cc4}: '𐳄'
SmallLetterEnc\u{10cc5}: '𐳅'
SmallLetterEcs\u{10cc6}: '𐳆'
SmallLetterEd\u{10cc7}: '𐳇'
SmallLetterAnd\u{10cc8}: '𐳈'
SmallLetterE\u{10cc9}: '𐳉'
SmallLetterCloseE\u{10cca}: '𐳊'
SmallLetterEe\u{10ccb}: '𐳋'
SmallLetterEf\u{10ccc}: '𐳌'
SmallLetterEg\u{10ccd}: '𐳍'
SmallLetterEgy\u{10cce}: '𐳎'
SmallLetterEh\u{10ccf}: '𐳏'
SmallLetterI\u{10cd0}: '𐳐'
SmallLetterIi\u{10cd1}: '𐳑'
SmallLetterEj\u{10cd2}: '𐳒'
SmallLetterEk\u{10cd3}: '𐳓'
SmallLetterAk\u{10cd4}: '𐳔'
SmallLetterUnk\u{10cd5}: '𐳕'
SmallLetterEl\u{10cd6}: '𐳖'
SmallLetterEly\u{10cd7}: '𐳗'
SmallLetterEm\u{10cd8}: '𐳘'
SmallLetterEn\u{10cd9}: '𐳙'
SmallLetterEny\u{10cda}: '𐳚'
SmallLetterO\u{10cdb}: '𐳛'
SmallLetterOo\u{10cdc}: '𐳜'
SmallLetterNikolsburgOe\u{10cdd}: '𐳝'
SmallLetterRudimentaOe\u{10cde}: '𐳞'
SmallLetterOee\u{10cdf}: '𐳟'
SmallLetterEp\u{10ce0}: '𐳠'
SmallLetterEmp\u{10ce1}: '𐳡'
SmallLetterEr\u{10ce2}: '𐳢'
SmallLetterShortEr\u{10ce3}: '𐳣'
SmallLetterEs\u{10ce4}: '𐳤'
SmallLetterEsz\u{10ce5}: '𐳥'
SmallLetterEt\u{10ce6}: '𐳦'
SmallLetterEnt\u{10ce7}: '𐳧'
SmallLetterEty\u{10ce8}: '𐳨'
SmallLetterEch\u{10ce9}: '𐳩'
SmallLetterU\u{10cea}: '𐳪'
SmallLetterUu\u{10ceb}: '𐳫'
SmallLetterNikolsburgUe\u{10cec}: '𐳬'
SmallLetterRudimentaUe\u{10ced}: '𐳭'
SmallLetterEv\u{10cee}: '𐳮'
SmallLetterEz\u{10cef}: '𐳯'
SmallLetterEzs\u{10cf0}: '𐳰'
SmallLetterEntDashShapedSign\u{10cf1}: '𐳱'
SmallLetterUs\u{10cf2}: '𐳲'
NumberOne\u{10cfa}: '𐳺'
NumberFive\u{10cfb}: '𐳻'
NumberTen\u{10cfc}: '𐳼'
NumberFifty\u{10cfd}: '𐳽'
NumberOneHundred\u{10cfe}: '𐳾'
Methods
impl OldHungarian[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case